@@ -1,6 +1,19 @@
-# file MASS/lda.q
+# file MASS/R/lda.R
 # copyright (C) 1994-2004 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 lda <- function(x, ...) UseMethod("lda")
 
 
@@ -15,7 +28,7 @@ lda.formula <- function(formula, data, ..., subset, na.action)
     Terms <- attr(m, "terms")
     grouping <- model.response(m)
     x <- model.matrix(Terms, m)
-    xint <- match("(Intercept)", colnames(x), nomatch=0)
+    xint <- match("(Intercept)", colnames(x), nomatch=0L)
     if(xint > 0) x <- x[, -xint, drop=FALSE]
     res <- lda.default(x, grouping, ...)
     res$terms <- Terms
@@ -212,7 +225,7 @@ predict.lda <- function(object, newdata, prior = object$prior, dimen,
                 .checkMFClasses(cl, newdata)
         }
         x <- model.matrix(Terms, newdata, contrasts = object$contrasts)
-        xint <- match("(Intercept)", colnames(x), nomatch=0)
+        xint <- match("(Intercept)", colnames(x), nomatch=0L)
         if(xint > 0) x <- x[, -xint, drop=FALSE]
     } else { #
     # matrix or data-frame fit
@@ -314,7 +327,7 @@ plot.lda <- function(x, panel = panel.lda, ..., cex=0.7,
         data <- model.frame(x)
         X <- model.matrix(delete.response(Terms), data)
         g <- model.response(data)
-        xint <- match("(Intercept)", colnames(X), nomatch=0)
+        xint <- match("(Intercept)", colnames(X), nomatch=0L)
         if(xint > 0) X <- X[, -xint, drop=FALSE]
     } else { #
     # matrix or data-frame fit
@@ -424,7 +437,7 @@ pairs.lda <- function(x, labels = colnames(x), panel = panel.lda,
         data <- model.frame(x)
         X <- model.matrix(delete.response(Terms), data)
         g <- model.response(data)
-        xint <- match("(Intercept)", colnames(X), nomatch=0)
+        xint <- match("(Intercept)", colnames(X), nomatch=0L)
         if(xint > 0) X <- X[, -xint, drop=FALSE]
     } else { #
     # matrix or data-frame fit
