@@ -1,12 +1,27 @@
-# file spatial/pp.q copyright (C) 1994-9 W. N. Venables and B. D. Ripley
+# file spatial/R/pp.R
+# copyright (C) 1994-9 W. N. Venables and B. D. Ripley
+#
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 #
 ppinit <- function(file)
 {
   tfile <- file
   t1file <- system.file("ppdata", file, package="spatial")
-  if(nchar(t1file) > 0) tfile <- t1file
+  if(nzchar(t1file)) tfile <- t1file
   h <- scan(tfile, list(xl = 0, xu = 0, yl = 0, yu = 0, fac = 0),
-	    n = 5, skip = 2, quiet = TRUE)
+	    n = 5L, skip = 2L, quiet = TRUE)
   pp <- scan(tfile, list(x = 0, y = 0), skip = 3, quiet = TRUE)
   pp$x <- pp$x/h$fac
   pp$y <- pp$y/h$fac
@@ -25,10 +40,10 @@ Kfn <- function(pp, fs, k = 100)
 	  as.integer(length(pp$x)),
 	  k1 = as.integer(k),
 	  h = double(k),
-	  dmin = double(1),
-	  lm = double(1),
+	  dmin = double(1L),
+	  lm = double(1L),
 	  as.double(fs))
-  list(y = z$h[1:z$k1], x = (seq(1:z$k1) * fs)/k, k = k,
+  list(y = z$h[1L:z$k1], x = (seq(1L:z$k1) * fs)/k, k = k,
        dmin = z$dmin, lm = max(z$dmin, z$lm),
        call=match.call())
 }
@@ -162,7 +177,7 @@ pplik <- function(pp, R, ng=50, trace=FALSE)
   if(target == 0) return(0)
   tmp <- pplikfn(1, R, n, pp$x, pp$y, ng, target, FALSE)
   if(tmp <= 0) return(1)
-  stats::uniroot(pplikfn, c(0,1),
+  stats::uniroot(pplikfn, interval=c(0,1),
                  R=R, n=n, x=pp$x, y=pp$y, ng=ng, target=target,
                  trace=trace)$root
 }
